summaryrefslogtreecommitdiffstats
path: root/src/k3btempdirselectionwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/k3btempdirselectionwidget.h')
-rw-r--r--src/k3btempdirselectionwidget.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/k3btempdirselectionwidget.h b/src/k3btempdirselectionwidget.h
index bc0524a..639e7b6 100644
--- a/src/k3btempdirselectionwidget.h
+++ b/src/k3btempdirselectionwidget.h
@@ -23,7 +23,7 @@
class TQTimer;
class TQLabel;
class KURLRequester;
-class KConfigBase;
+class TDEConfigBase;
/**
@@ -45,7 +45,7 @@ class K3bTempDirSelectionWidget : public TQGroupBox
/**
* \return Free space in KB
* FIXME: use KIO::filesize_t and return the number of bytes
*/
unsigned long freeTempSpace() const;
TQString tempPath() const;
@@ -60,7 +60,7 @@ class K3bTempDirSelectionWidget : public TQGroupBox
public slots:
void setTempPath( const TQString& );
void setSelectionMode( int mode );
- void setNeededSize( KIO::filesize_t bytes );
+ void setNeededSize( TDEIO::filesize_t bytes );
/**
* In file selection mode if the user enters a directory name it will
@@ -74,8 +74,8 @@ class K3bTempDirSelectionWidget : public TQGroupBox
*/
void saveConfig();
- void readConfig( KConfigBase* );
- void saveConfig( KConfigBase* );
+ void readConfig( TDEConfigBase* );
+ void saveConfig( TDEConfigBase* );
private slots:
void slotUpdateFreeTempSpace();
@@ -45,7 +45,7 @@ class K3bTempDirSelectionWidget : public TQGroupBox
/**
* \return Free space in KB
- * FIXME: use KIO::filesize_t and return the number of bytes
+ * FIXME: use TDEIO::filesize_t and return the number of bytes
*/
unsigned long freeTempSpace() const;